@@ -38,7 +38,7 @@
 
 /*** cpp *********************************************************************/
 
-#define SHOUTCAST_ROOT		"http://www.shoutcast.com/"
+#define SHOUTCAST_ROOT		"http://classic.shoutcast.com/"
 
 #define MAX_STREAMS_PER_PAGE	100 /* enforced by SHOUTcast */
 
